==> question2answer-1.5-language-pt-BR.zip: pt/qa-lang-profile.php <==
<?php
	
/*
	Question2Answer (c) Gideon Greenspan

	http://www.question2answer.org/

	
	File: qa-include/qa-lang-profile.php
	Version: See define()s at top of qa-include/qa-base.php
	Description: Language phrases for user profile page


	This program is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 2
	of the License, or (at your option) any later version.
	
	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	More about this license: http://www.question2answer.org/license.php
*/

	return array(
		'1_chosen_as_best' => ' (1 escolhida como a melhor)',
		'1_down_vote' => '1 voto negativo',
		'1_up_vote' => '1 voto positivo',
		'1_with_best_chosen' => ' (1 com melhor resposta escolhida)',
		'activity_by_x' => 'Atividade de ^',
		'answers' => 'Respostas:',
		'bonus_points' => 'Pontos de bônus:',
		'comments' => 'Comentários:',
		'extra_privileges' => 'Privilégios:',
		'gave_out' => 'Distribuiu:',
		'my_account_title' => 'Detalhes de minha conta',
		'no_posts_by_x' => 'Nenhuma publicação de ^',
		'permit_anon_view_ips' => 'Ver IPs de anônimos',
		'permit_close_q' => 'Fechar qualquer pergunta',
		'permit_delete_hidden' => 'Excluir publicações ocultas',
		'permit_edit_a' => 'Editar respostas',
		'permit_edit_c' => 'Editar comentários',
		'permit_edit_q' => 'Editar perguntas',
		'permit_flag' => 'Denunciar',
		'permit_hide_show' => 'Ocultar e republicar',
		'permit_moderate' => 'Aprovar ou rejeitar publicações',
		'permit_post_a' => 'Responder',
		'permit_post_c' => 'Comentar',
		'permit_post_q' => 'Perguntar',
		'permit_recat' => 'Recategorizar qualquer pergunta',
		'permit_retag' => 'Reclassificar qualquer pergunta',
		'permit_select_a' => 'Escolher a melhor resposta de qualquer pergunta',
		'permit_view_q_page' => 'Ver página de perguntas',
		'permit_vote_a' => 'Votar em respostas',
		'permit_vote_down' => 'Dar votos negativos',
		'permit_vote_q' => 'Votar em perguntas',
		'questions' => 'Perguntas:',
		'ranked_x' => ' (classificado em #^)',
		'received' => 'Recebeu:',
		'recent_activity_by_x' => 'Atividade recente de ^',
		'score' => 'Pontuação:',
		'send_private_message' => ' - ^1enviar mensagem privada^2',
		'set_bonus_button' => 'Atualizar bônus',
		'title' => 'Título:',
		'user_x' => 'Usuário ^',
		'voted_on' => 'Votou em:',
		'x_chosen_as_best' => ' (^ escolhidas como a melhor)',
		'x_down_votes' => '^ votos negativos',
		'x_up_votes' => '^ votos positivos',
		'x_with_best_chosen' => ' (^ com melhor resposta escolhida)',
	);
	

/*
	Omit PHP closing tag to help avoid accidental output
*/

==> question2answer-1.6-language-pt-BR.zip: pt/qa-lang-profile.php <==
<?php
	
/*
	Question2Answer (c) Gideon Greenspan

	http://www.question2answer.org/

	
	File: qa-include/qa-lang-profile.php
	Version: See define()s at top of qa-include/qa-base.php
	Description: Language phrases for user profile page


	This program is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 2
	of the License, or (at your option) any later version.
	
	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	More about this license: http://www.question2answer.org/license.php
*/

	return array(
		'1_chosen_as_best' => ' (1 escolhida como a melhor)',
		'1_down_vote' => '1 voto negativo',
		'1_up_vote' => '1 voto positivo',
		'1_with_best_chosen' => ' (1 com melhor resposta escolhida)',
		'activity_by_x' => 'Atividade de ^',
		'answers_by_x' => 'Respostas de ^',
		'answers' => 'Respostas:',
		'bonus_points' => 'Pontos de bônus:',
		'comments' => 'Comentários:',
		'delete_wall_post_popup' => 'Apagar essa publicação do mural',
		'extra_privileges' => 'Privilégios:',
		'gave_out' => 'Distribuiu:',
		'my_account_title' => 'Detalhes de minha conta',
		'no_answers_by_x' => 'Nenhuma resposta de ^',
		'no_posts_by_x' => 'Nenhuma publicação de ^',
		'no_questions_by_x' => 'Nenhuma pergunta de ^',
		'permit_anon_view_ips' => 'Ver IPs de anônimos',
		'permit_close_q' => 'Fechar qualquer pergunta',
		'permit_delete_hidden' => 'Excluir publicações ocultas',
		'permit_edit_a' => 'Editar respostas',
		'permit_edit_c' => 'Editar comentários',
		'permit_edit_q' => 'Editar perguntas',
		'permit_edit_silent' => 'Editar publicações secretamente',
		'permit_flag' => 'Denunciar',
		'permit_hide_show' => 'Ocultar e republicar',
		'permit_moderate' => 'Aprovar ou rejeitar publicações',
		'permit_post_a' => 'Responder',
		'permit_post_c' => 'Comentar',
		'permit_post_q' => 'Perguntar',
		'permit_post_wall' => 'Publicar em murais',
		'permit_recat' => 'Recategorizar qualquer pergunta',
		'permit_retag' => 'Reclassificar qualquer pergunta',
		'permit_select_a' => 'Escolher a melhor resposta de qualquer pergunta',
		'permit_view_q_page' => 'Ver página de perguntas',
		'permit_view_voters_flaggers' => 'Ver quem votou ou denunciou publicações',
		'permit_vote_a' => 'Votar em respostas',
		'permit_vote_down' => 'Dar votos negativos',
		'permit_vote_q' => 'Votar em perguntas',
		'post_wall_blocked' => 'Este usuário desativou novas publicações em seu mural',
		'post_wall_button' => 'Adicionar publicação no mural',
		'post_wall_empty' => 'Digite algo para publicar neste mural',
		'post_wall_limit' => 'Você não pode publicar neste mural por uma hora',
		'post_wall_must_be_approved' => 'Sua conta deve ser aprovada antes de publicar neste mural.',
		'post_wall_must_confirm' => '^5Confirme o seu e-mail^6 para publicar neste mural.',
		'post_wall_must_login' => '^1Entre^2 ou ^3registre-se^4 para publicar neste mural.',
		'questions_by_x' => 'Perguntas de ^',
		'questions' => 'Perguntas:',
		'ranked_x' => ' (classificado em #^)',
		'received' => 'Recebeu:',
		'recent_activity_by_x' => 'Atividade recente de ^',
		'score' => 'Pontuação:',
		'send_private_message' => ' - ^1enviar mensagem privada^2',
		'set_bonus_button' => 'Atualizar bônus',
		'title' => 'Título:',
		'user_x' => 'Usuário ^',
		'voted_on' => 'Votou em:',
		'wall_for_x' => 'Mural de ^',
		'wall_view_more' => 'Ver mais publicações do mural...',
		'x_chosen_as_best' => ' (^ escolhidas como a melhor)',
		'x_down_votes' => '^ votos negativos',
		'x_up_votes' => '^ votos positivos',
		'x_with_best_chosen' => ' (^ com melhor resposta escolhida)',
	);
	

/*
	Omit PHP closing tag to help avoid accidental output
*/
